Learn R Programming

btergm (version 1.8.2)

edgeprob: Compute all dyadic edge probabilities for an ERGM or TERGM.

Description

edgeprob is a convenience function that creates a data frame with all dyads in the ERGM or TERGM along with their edge probabilities and their predictor values (i.e., change statistics). This is useful for creating marginal effects plots or contrasting multiple groups of dyads. This function works faster than the interpret function. See also the interpret help page.

Usage

edgeprob(object, verbose = FALSE)

Arguments

object
An ergm, btergm, or mtergm object.
verbose
Print details?

Value

The first variable in the resulting data frame contains the edge value (i.e., the dependent variable, which is usually binary). The next variables contain all the predictors from the ERGM or TERGM (i.e., the change statistics). The next three variables contain the indices of the sender (i), the receiver (j), and the time step (t). These three indices serve to identify the dyad. The last variable contains the computed edge probabilities.

See Also

interpret btergm-package btergm