Rdocumentation
powered by
Learn R Programming
btergm (version 1.8.2)
getformula: Extract the formula from a model.
Description
Extract the model formula from ergm or btergm objects.
Usage
"getformula"(x)
"getformula"(x)
"getformula"(x)
Arguments
x
A model object, for example a
btergm
or an
ergm
object.
Details
Extract the model formula from ergm or btergm objects.
See Also
gof