"plot"(x, relative = TRUE, transform = function(x) x, xlim = NULL, main = x$label, xlab = x$label, ylab = "Frequency", border = "darkgray", boxplot.lwd = 0.8, outline = FALSE, median = TRUE, median.col = "black", median.lty = "solid", median.lwd = 2, mean = TRUE, mean.col = "black", mean.lty = "dashed", mean.lwd = 1, ...)
"plot"(x, mfrow = TRUE, ...)
"plot"(x, add = FALSE, main = x$label, avg = c("none", "horizontal", "vertical", "threshold"), spread.estimate = c("boxplot", "stderror", "stddev"), lwd = 3, rgraph = TRUE, col = "#5886be", random.col = "#5886be44", pr.poly = 0, ...)
"plot"(x, add = FALSE, main = x$label, avg = c("none", "horizontal", "vertical", "threshold"), spread.estimate = c("boxplot", "stderror", "stddev"), lwd = 3, rgraph = TRUE, col = "#bd0017", random.col = "#bd001744", ...)
"plot"(x, main = x$label, roc.avg = c("none", "horizontal", "vertical", "threshold"), roc.spread.estimate = c("boxplot", "stderror", "stddev"), roc.lwd = 3, roc.rgraph = TRUE, roc.col = "#bd0017", roc.random.col = "#bd001744", pr.avg = c("none", "horizontal", "vertical", "threshold"), pr.spread.estimate = c("boxplot", "stderror", "stddev"), pr.lwd = 3, pr.rgraph = TRUE, pr.col = "#5886be", pr.random.col = "#5886be44", pr.poly = 0, ...)
"plot"(x, main = x$label, sim.hist = TRUE, sim.bar = TRUE, sim.density = TRUE, obs.hist = FALSE, obs.bar = TRUE, obs.density = TRUE, sim.adjust = 1, obs.adjust = 1, sim.lwd = 2, obs.lwd = 2, sim.col = "black", obs.col = "red", ...)
"print"(x, ...)
"print"(x, ...)
"print"(x, ...)
"print"(x, ...)
"print"(x, ...)
"print"(x, ...)"none" (plot all curves separately), "horizontal" (horizontal averaging), "vertical" (vertical averaging), and "threshold" (threshold (= cutoff) averaging). Note that while threshold averaging is always feasible, vertical and horizontal averaging are not well-defined if the graph cannot be represented as a function x->y and y->x, respectively. More information can be obtained from the help pages of the ROCR package, the functions of which are employed here. mfrow = FALSE), or should all statistics be aligned in a single diagram (mfrow = TRUE)? Returning the plots separately can be helpful if the output is redirected to a multipage PDF or TIFF file. "none" (plot all curves separately), "horizontal" (horizontal averaging), "vertical" (vertical averaging), and "threshold" (threshold (= cutoff) averaging). Note that while threshold averaging is always feasible, vertical and horizontal averaging are not well-defined if the graph cannot be represented as a function x->y and y->x, respectively. More information can be obtained from the help pages of the ROCR package, the functions of which are employed here. 0 is set, nothing special happens. If a value of 1 is set, a straight line is fitted through the PR curve and displayed. Values between 2 and 9 fit higher-order polynomial curves through the PR curve and display the resulting curve. This argument allows to check whether the imputation of the first precision value in the PR curve yielded a reasonable result (in case the value had to be imputed). "stderror"), standard deviation bars ("stddev"), or by using box plots ("boxplot"). Note that the function plotCI, which is used internally by the ROCR package to draw error bars, might raise a warning if the spread of the curves at certain positions is 0. More details can be found in the documentation of the ROCR package, the functions of which are employed here. "none" (plot all curves separately), "horizontal" (horizontal averaging), "vertical" (vertical averaging), and "threshold" (threshold (= cutoff) averaging). Note that while threshold averaging is always feasible, vertical and horizontal averaging are not well-defined if the graph cannot be represented as a function x->y and y->x, respectively. More information can be obtained from the help pages of the ROCR package, the functions of which are employed here. "stderror"), standard deviation bars ("stddev"), or by using box plots ("boxplot"). Note that the function plotCI, which is used internally by the ROCR package to draw error bars, might raise a warning if the spread of the curves at certain positions is 0. More details can be found in the documentation of the ROCR package, the functions of which are employed here. "stderror"), standard deviation bars ("stddev"), or by using box plots ("boxplot"). Note that the function plotCI, which is used internally by the ROCR package to draw error bars, might raise a warning if the spread of the curves at certain positions is 0. More details can be found in the documentation of the ROCR package, the functions of which are employed here. transform = function(x) x^0.1 or a similar transformation of the values can be used. Note that logarithmic transformations often produce infinite values because log(0) = -Inf, so one should rather use something like transform = function(x) log1p to avoid infinite values. gof methods. xlim = 8. gof function and its methods. See the help page of gof-methods for details on how to compute gof.