Learn R Programming

btergm (version 1.7.3)

tergm-terms: Temporal dependencies for TERGMs

Description

Network statistics that span multiple time points.

Arguments

Details

In addition to the ERGM user terms that can be estimated within a single network (see ergm-terms), the btergm package provides additional model terms that can be used within a formula. These additional statistics span multiple time periods and are therefore called "temporal dependencies." Examples include memory terms (i.e., positive autoregression, dyadic stability, edge innovation, or edge loss), delayed reciprocity or mutuality, and time covariates (i.e., functions of time or interactions with time):

[object Object],[object Object],[object Object]

See Also

btergm-package btergm preprocess timecov ergm-terms