btergm-package: Temporal Exponential Random Graph Models by Bootstrapped Pseudolikelihood
Description
Temporal Exponential Random Graph Models (TERGM) estimated by maximum pseudolikelihood with bootstrapped confidence intervals or Markov Chain Monte Carlo maximum likelihood. Goodness of fit assessment for ERGMs, TERGMs, and SAOMs. Micro-level interpretation of ERGMs and TERGMs.Details
The btergm package implements TERGMs with MPLE and bootstrapped confidence intervals (btergm function) or MCMC MLE (mtergm function). Use the preprocess, adjust, handleMissings, and timecov functions for data preparation for TERGMs. Goodness of fit assessment for ERGMs, TERGMs, SAOMs, and dyadic independence models is possible with the generic gof function and its various methods. New networks can be simulated from TERGMs using the simulate.btergm function. The package also implements micro-level interpretation for ERGMs and TERGMs using the interpret function. Furthermore, the package contains the chemnet and knecht datasets for estimating (T)ERGMs. To display citation information, type citation("btergm").