Usage
"checkdegeneracy"(object, ...)
"checkdegeneracy"(object, nsim = 1000, MCMC.interval = 1000, MCMC.burnin = 10000, verbose = FALSE)
"print"(x, center = FALSE, t = 1:length(x$sim), terms = 1:length(x$target.stats[[1]]), ...)
"plot"(x, center = TRUE, t = 1:length(x$sim), terms = 1:length(x$target.stats[[1]]), vbar = TRUE, main = NULL, xlab = NULL, target.col = "red", target.lwd = 3, ...)
Arguments
object
A btergm or mtergm object, as estimated using the btergm or mtergm function.
nsim
The number of networks to be simulated at each time step. This number should be sufficiently large for a meaningful comparison. If possible, much more than 1,000 simulations.
MCMC.burnin
Internally, this package uses the simulation facilities of the ergm package to create new networks against which to compare the original network(s) for goodness-of-fit assessment. This argument sets the MCMC burnin to be passed over to the simulation command. The default value is 10000. There is no general rule of thumb on the selection of this parameter, but if the results look suspicious (e.g., when the model fit is perfect), increasing this value may be helpful.
MCMC.interval
Internally, this package uses the simulation facilities of the ergm package to create new networks against which to compare the original network(s) for goodness-of-fit assessment. This argument sets the MCMC interval to be passed over to the simulation command. The default value is 1000, which means that every 1000th simulation outcome from the MCMC sequence is used. There is no general rule of thumb on the selection of this parameter, but if the results look suspicious (e.g., when the model fit is perfect), increasing this value may be helpful.
x
A degeneracy object created by the checkdegeneracy function.
center
If TRUE, print/plot the simulated minus the target statistics, with an expected value of 0 in a non-degenerate model. If FALSE, print/plot the distribution of simulated statistics and show the target statistic separately.
t
Time indices to include, e.g., t = 2:4 for time steps 2 to 4.
terms
Indices of the model terms to include, e.g., terms = 1:3 includes the first three statistics.
vbar
Show vertical bar for target statistic in histogram.
main
Main title of the plot.
xlab
Label on the x-axis. Defaults to the name of the statistic.
target.col
Color of the vertical bar for the target statistic. Defaults to red.
target.lwd
Line width of the vertical bar for the target statistic. Defaults to 3.
...
Arbitrary further arguments.