Learn R Programming

btergm (version 1.6.5)

checkdegeneracy: Degeneracy check for btergm objects

Description

Assess degeneracy of btergm models.

Usage

checkdegeneracy(object, nsim = 1000, MCMC.interval = 1000, 
    MCMC.burnin = 10000, verbose = FALSE)

## S3 method for class 'degeneracy': print(x, ...)

Arguments

object
A btergm object, as estimated using the btergm function.
nsim
The number of networks to be simulated at each time step. This number should be sufficiently large for a meaningful comparison. If possible, much more than 1,000 simulations.
MCMC.burnin
Internally, this package uses the simulation facilities of the ergm package to create new networks against which to compare the original network(s) for goodness-of-fit assessment. This argument sets the MCMC burnin to be passed over to the simu
MCMC.interval
Internally, this package uses the simulation facilities of the ergm package to create new networks against which to compare the original network(s) for goodness-of-fit assessment. This argument sets the MCMC interval to be passed over to the si
verbose
Print details?
x
A degeneracy object created by the checkdegeneracy function.
...
Arbitrary further arguments.

Details

The degeneracy function implements a degeneracy check for btergm objects by comparing the global statistics of simulated networks to those of the observed networks at each observed time step. If the global statistics differ significantly, this is indicated by small p-values. If there are many significant results, this indicates degeneracy.

See Also

btergm-package btergm gof