checkdegeneracy(object, nsim = 1000, MCMC.interval = 1000,
MCMC.burnin = 10000, verbose = FALSE)## S3 method for class 'degeneracy':
print(x, ...)
btergm object, as estimated using the btergm function.degeneracy object created by the checkdegeneracy function.degeneracy function implements a degeneracy check for btergm objects by comparing the global statistics of simulated networks to those of the observed networks at each observed time step. If the global statistics differ significantly, this is indicated by small p-values. If there are many significant results, this indicates degeneracy.