edgeprob is a convenience function that creates a data frame with
all dyads in the ERGM or TERGM along with their edge probabilities and
their predictor values (i.e., change statistics). This is useful for
creating marginal effects plots or contrasting multiple groups of
dyads. This function works faster than the interpret function.
See also the interpret help page.
edgeprob(object, verbose = FALSE)ergm, btergm, or mtergm object.